@@ -1,5 +1,14 @@
 var NAVTREEINDEX7 =
 {
+"structpw__device__events.html#a01a060fea8c0b9d8ccd4eb2aff2848e6":[10,0,32,0],
+"structpw__device__events.html#a75a9ec87b680ae9f45503fbbc1b0fcc9":[10,0,32,1],
+"structpw__device__events.html#adbe2ffa9bd2bcf75f82ce7cfd99ebb29":[10,0,32,2],
+"structpw__device__info.html":[10,0,33],
+"structpw__device__info.html#a05bdd1fb2e89f763b27fe8784cb3e5c2":[10,0,33,1],
+"structpw__device__info.html#a3c53740de36a82a69153911b6777f66e":[10,0,33,0],
+"structpw__device__info.html#a8167e42a1f2bebaddedd6987b9dd39ac":[10,0,33,4],
+"structpw__device__info.html#accce9f7bcbbb1e5142298f18ce03d799":[10,0,33,2],
+"structpw__device__info.html#ad8eb88e166e5527d4d5f418e591274c0":[10,0,33,3],
 "structpw__device__methods.html":[10,0,34],
 "structpw__device__methods.html#a50406b74540f4535df9b01ae15cfcfe0":[10,0,34,3],
 "structpw__device__methods.html#a8210738d5878d65481bc918ff935aa80":[10,0,34,1],
@@ -240,14 +249,5 @@ var NAVTREEINDEX7 =
 "structpw__properties.html#a30bb01472ad7feccd59e8b589e2896ee":[10,0,86,10],
 "structpw__properties.html#a6473c3fdc688733f1db2e8d645ba94f4":[10,0,86,4],
 "structpw__properties.html#a674f4f6bd81ec0b229c0b6af88774b7a":[10,0,86,3],
-"structpw__properties.html#a70798a7b7de258dff8e02f9fcbf5210d":[10,0,86,13],
-"structpw__properties.html#a70aa5816bde60f5511f2308971794881":[10,0,86,14],
-"structpw__properties.html#a7a71d043d7edca5a1b3c6e7b95931ab0":[10,0,86,1],
-"structpw__properties.html#a7ab4c3f85931eab48ad91352d44be9d3":[10,0,86,2],
-"structpw__properties.html#a8003e978689f764bb7bd2a3ab2d46a87":[10,0,86,15],
-"structpw__properties.html#aa31ae496c298076852173e46a8c58da5":[10,0,86,6],
-"structpw__properties.html#ab8d32d79721d753deb979f2698fff034":[10,0,86,9],
-"structpw__properties.html#aea9bdd771760e44ca7d77b5113297610":[10,0,86,7],
-"structpw__properties.html#aef040055887634f636bb26594091c31c":[10,0,86,5],
-"structpw__protocol__client.html":[10,0,88]
+"structpw__properties.html#a70798a7b7de258dff8e02f9fcbf5210d":[10,0,86,13]
 };
